--
-- MapFruitTrigger
--
-- M@D Author  Headshot XXL
-- M@D date 20.09.2009
--
--Updated by @po@lypse


MapFruitTrigger = {};
MapFruitTrigger.fruitTrigger = {};

function MapFruitTrigger:onCreate(id)
	
	MapFruitTrigger:load(id);	
end;

MapFruitTriggerOnCreate = MapFruitTrigger.onCreate;


function MapFruitTrigger:load(id)
	
    addTrigger(id, "fruitTriggerCallback", self);
	
	local entry = {};	
	local fruitType = getUserAttribute(id, "fruitType");		
	local key = "FRUITTYPE_"..string.upper(fruitType);
        local fillFruit = FruitUtil[key];
	entry.fillType = FruitUtil.fruitTypeToFillType[fillFruit];  
	entry.fillSpeed = getUserAttribute(id, "fillSpeed");
	entry.priceMultipliers = getUserAttribute(id, "priceMultipliers");
	entry.id = id;	
	table.insert(self.fruitTrigger, entry);

	self.trailerInTrigger = 0;	
	self.fruitTriggerId = 0;
	self.id = id;
	self.fill = false;
	self.printText = false;

        self.siloParticleSystemRoot = loadI3DFile("data/vehicles/particleSystems/wheatParticleSystemLong.i3d");
  local x,y,z = localToWorld(self.id, -0.05, 0.15, 0.05);
  print("x="..x.." y="..y.." z="..z);
  setTranslation(self.siloParticleSystemRoot, x, y, z);
  link(getRootNode(), self.siloParticleSystemRoot);

  for i=0, getNumOfChildren(self.siloParticleSystemRoot)-1 do
    local child = getChildAt(self.siloParticleSystemRoot, i);
    if getClassName(child) == "Shape" then
      local geometry = getGeometry(child);
      if geometry ~= 0 then
        if getClassName(geometry) == "ParticleSystem" then
          self.siloParticleSystem = geometry;
          
        end;
      end;
    end;
  end;

  if self.siloParticleSystem ~= nil then
    setEmittingState(self.siloParticleSystem, false);
   
  end;
end;


function MapFruitTrigger:loadMap(name)
end;

function MapFruitTrigger:deleteMap()
end;

function MapFruitTrigger:delete()
end;

function MapFruitTrigger:mouseEvent(posX, posY, isDown, isUp, button)
end;

function MapFruitTrigger:keyEvent(unicode, sym, modifier, isDown)
end;

function MapFruitTrigger:update(dt)

	if self.trailerInTrigger ~= 0 then	
		
		if InputBinding.hasEvent(InputBinding.MAPFRUITTRIGGER_FILL)  then
			self.fill = not self.fill; 
		end; 
		if self.fill and self.printText then
			g_currentMission:addExtraPrintText("Touche * : Stop load"); 
		elseif self.printText then
			g_currentMission:addExtraPrintText("Touche * : Start load"); 
		end; 
		
		
		self.printText = false;
		for i=1, table.getn(self.fruitTrigger) do
			if self.fruitTrigger[i].id == self.fruitTriggerId then				
				local attachable = g_currentMission.objectToTrailer[self.trailerInTrigger];
				if attachable ~= nil then
					if attachable.fillTypes ~= nil and attachable.setFillLevel ~= nil and attachable.fillLevel ~= nil then
						if self.fruitTrigger[i].fillType == attachable.currentFillType or attachable.currentFillType == FruitUtil.FRUITTYPE_UNKNOWN or attachable.fillLevel ~= nil then
							if attachable.fillLevel < attachable.capacity and attachable:allowFillType(self.fruitTrigger[i].fillType, true) then
                                                             if attachable.isShovel then
                                                              self.fill = true;
                                                             end;
								if self.fill then
									local deltaFillLevel = dt*self.fruitTrigger[i].fillSpeed;
									attachable:setFillLevel(attachable.fillLevel+deltaFillLevel, self.fruitTrigger[i].fillType);
									-- increase money according to price of current fill type
									local pricesPerLiter =  FruitUtil.fruitIndexToDesc[self.fruitTrigger[i].fillType].pricePerLiter;
									local priceMultiplier = self.fruitTrigger[i].priceMultipliers;
									local difficultyMultiplier = math.max(3 * (3 - g_currentMission.missionStats.difficulty), 1); -- 1  3  6
									local money = pricesPerLiter * 1 * difficultyMultiplier * deltaFillLevel;
									g_currentMission.missionStats.money = g_currentMission.missionStats.money - money;
                                                                        setEmittingState(self.siloParticleSystem, true);
								end;
								self.printText = true;
							else
								self.fill = false;
                                                                setEmittingState(self.siloParticleSystem, false);
							end;
						end;
					end;
				end;
			end;			
		end;
	else
		self.fill = false;
                setEmittingState(self.siloParticleSystem, false);
	end;
   if not self.fill then
    setEmittingState(self.siloParticleSystem, false);
   end;
	
end;

function MapFruitTrigger:draw()
end;

function MapFruitTrigger:fruitTriggerCallback(triggerId, otherId, onEnter, onLeave, onStay, otherShapeId)

    if onEnter then
		if otherId ~= nil then			
			self.trailerInTrigger = otherId;
			self.fruitTriggerId = triggerId;		
		end;		
	elseif onLeave then
		self.trailerInTrigger = 0;
		self.fruitTriggerId = 0;
	elseif onStay then
		if otherId ~= nil then			
			self.trailerInTrigger = otherId;
			self.fruitTriggerId = triggerId;		
		end;
	end;
	
end;

addModEventListener(MapFruitTrigger);

